| Title: | Retrieve R Package News Files |
|---|---|
| Description: | Read R package news files, regardless of whether or not the package is installed. |
| Authors: | Owen Jones [aut, cre] |
| Maintainer: | Owen Jones <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.2 |
| Built: | 2026-05-10 07:59:37 UTC |
| Source: | https://github.com/owenjonesuob/pkgnews |
Retrieve the NEWS file of a package as a character vector.
news(package, installed_only = FALSE, allow_changelog = TRUE, width = NULL)news(package, installed_only = FALSE, allow_changelog = TRUE, width = NULL)
package |
Character string giving the name of an R package. |
installed_only |
Only check installed packages. |
allow_changelog |
Whether to try and find a ChangeLog file if the NEWS can't be found. |
width |
An optional positive integer - see |
A character vector containing the contents of the package's NEWS file
(or possibly the ChangeLog file, if allow_changelog = TRUE). An error is
thrown if no news could be found.
## Not run: news("pkgnews")## Not run: news("pkgnews")